# Meta  SDK


Документация: http://metasdk.readthedocs.io

Полный список примеров: https://github.com/devision-io/metasdk/tree/master/metasdk/examples

## Структура каталогов
- doc - Автоматически собираемая документация
- metasdk
  - services - API службы, доступные к управелению через SDK
  - logger - общий и массовый логгер, вызывать стоит **только** через **META.log**  
  - examples - примеры работы с сервисами и прочей функциональостью SDK 
  - tools - скрипты для **только** консольных вызовов через python -m. Например тут вспомогальеные скрипты деплоя и разработки API сервисов 